"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.hoist = hoist;

var _TBlock = require("../tree/TBlock");

var _TBlockAnchor = require("../tree/TBlockAnchor");

var _TPhrasing = require("../tree/TPhrasing");

var _TPhrasingAnchor = require("../tree/TPhrasingAnchor");

var _TText = require("../tree/TText");

function groupText(tnode, wrappernode) {
  let newChildren = [];
  let wrapper = wrappernode.newEmpty();

  for (const child of tnode.children) {
    if (child instanceof _TText.TText || child instanceof _TPhrasing.TPhrasing) {
      wrapper.children.push(child);
    } else {
      if (wrapper.children.length) {
        newChildren.push(wrapper);
        wrapper = wrappernode.newEmpty();
      }

      if (wrappernode instanceof _TPhrasingAnchor.TPhrasingAnchor) {
        const nextChild = new _TBlockAnchor.TBlockAnchor({ ...child.cloneInitParams(),
          href: wrappernode.href,
          parentStyles: wrappernode.parentStyles
        });
        nextChild.bindChildren(child.children);
        newChildren.push(nextChild);
      } else {
        newChildren.push(child);
      }
    }
  }

  if (wrapper.children.length) {
    newChildren.push(wrapper);
  }

  tnode.bindChildren(newChildren);
  return tnode;
}

function hoistNode(tnode) {
  tnode.bindChildren(tnode.children.map(hoistNode));

  if (tnode instanceof _TPhrasing.TPhrasing) {
    for (const cnode of tnode.children) {
      if (cnode instanceof _TBlock.TBlock) {
        const newNode = new _TBlock.TBlock(tnode.cloneInitParams({
          parentStyles: cnode.parentStyles,
          styles: cnode.styles
        }));
        newNode.bindChildren(tnode.children);
        const output = groupText(newNode, tnode);
        return output;
      }
    }
  } else if (tnode instanceof _TBlock.TBlock) {
    if (tnode.children.length > 0) {
      const output = groupText(tnode, new _TPhrasing.TPhrasing({
        parentStyles: tnode.styles,
        stylesMerger: tnode.stylesMerger
      }));
      return output;
    }
  }

  return tnode;
}

function hoist(tree) {
  return hoistNode(tree);
}
//# sourceMappingURL=hoist.js.map