"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getElementModelFromTagName = getElementModelFromTagName;

var _cssProcessor = require("@native-html/css-processor");

var _HTMLElementModel = require("./HTMLElementModel");

const nativeTextFlow = {
  compatCategory: 'native',
  displayCategory: 'text',
  propagationCategory: 'flow'
};
const nativeBlockRetain = {
  compatCategory: 'native',
  displayCategory: 'block',
  propagationCategory: 'retain'
};
const nativeTextRetain = {
  compatCategory: 'native',
  displayCategory: 'text',
  propagationCategory: 'retain'
};
const webTextFlow = {
  compatCategory: 'web',
  displayCategory: 'text',
  propagationCategory: 'flow'
};

const bigMarginTopBottomPropsRegistry = _cssProcessor.CSSProcessedProps.new().withProperty('marginTop', 16, nativeBlockRetain) // TODO: 1em
.withProperty('marginBottom', 16, nativeBlockRetain); // TODO: 1em


const shortMarginTopBottomPropsRegistry = _cssProcessor.CSSProcessedProps.new().withProperty('marginTop', 8, nativeBlockRetain) // TODO: .5em
.withProperty('marginBottom', 8, nativeBlockRetain); // TODO: .5em


const lineThroughPropsRegistry = _cssProcessor.CSSProcessedProps.new().withProperty('textDecorationLine', 'line-through', nativeTextRetain);

const italicPropsRegistry = _cssProcessor.CSSProcessedProps.new().withProperty('fontStyle', 'italic', nativeTextFlow);

const monoPropsRegistry = _cssProcessor.CSSProcessedProps.new().withProperty('fontFamily', 'monospace', nativeTextFlow);

const boldPropsRegistry = _cssProcessor.CSSProcessedProps.new().withProperty('fontWeight', 'bold', nativeTextFlow);

const whiteSpacePrePropsRegistry = _cssProcessor.CSSProcessedProps.new().withProperty('whiteSpace', 'pre', webTextFlow);

const spacedBlockPropsRegistry = _cssProcessor.CSSProcessedProps.new().withProperty('marginLeft', 30, nativeBlockRetain).withProperty('marginRight', 30, nativeBlockRetain).merge(bigMarginTopBottomPropsRegistry);

const anchorPropsRegistry = _cssProcessor.CSSProcessedProps.new().withProperty('color', '#245dc1', nativeTextFlow).withProperty('textDecorationLine', 'underline', nativeTextRetain).withProperty('textDecorationColor', '#245dc1', nativeTextRetain);

const leftBorderQuote = _cssProcessor.CSSProcessedProps.new().withProperty('borderLeftWidth', 2, nativeBlockRetain).withProperty('borderLeftColor', 'gray', nativeBlockRetain);

const dottedUnderlinePropsRegistry = _cssProcessor.CSSProcessedProps.new().withProperty('textDecorationLine', 'underline', nativeTextRetain).withProperty('textDecorationStyle', 'dotted', nativeTextRetain);

const solidUnderlinePropsRegistry = _cssProcessor.CSSProcessedProps.new().withProperty('textDecorationLine', 'underline', nativeTextRetain).withProperty('textDecorationStyle', 'solid', nativeTextRetain);

const listPropsRegistry = _cssProcessor.CSSProcessedProps.new().withProperty('paddingLeft', 30, nativeBlockRetain) // TODO, support directional styles
.merge(bigMarginTopBottomPropsRegistry); // whitespace + mono + spacing


const prePropsRegistry = whiteSpacePrePropsRegistry.merge(monoPropsRegistry).merge(bigMarginTopBottomPropsRegistry);
const sectioningModelMap = {
  address: new _HTMLElementModel.HTMLElementModel({
    category: 'sectioning',
    tagName: 'address',
    defaultUACSSProcessedProps: italicPropsRegistry
  }),
  article: new _HTMLElementModel.HTMLElementModel({
    category: 'sectioning',
    tagName: 'article'
  }),
  aside: new _HTMLElementModel.HTMLElementModel({
    category: 'sectioning',
    tagName: 'aside'
  }),
  body: new _HTMLElementModel.HTMLElementModel({
    category: 'sectioning',
    tagName: 'body'
  }),
  footer: new _HTMLElementModel.HTMLElementModel({
    category: 'sectioning',
    tagName: 'footer'
  }),
  h1: new _HTMLElementModel.HTMLElementModel({
    category: 'sectioning',
    tagName: 'h1',
    defaultUACSSProcessedProps: _cssProcessor.CSSProcessedProps.new().withProperty('fontSize', 32, nativeTextFlow) // TODO 2em
    .withProperty('marginTop', 10.72, nativeTextFlow) // TODO 0.67em
    .withProperty('marginBottom', 10.72, nativeTextFlow) // TODO 0.67em
    .merge(boldPropsRegistry)
  }),
  h2: new _HTMLElementModel.HTMLElementModel({
    category: 'sectioning',
    tagName: 'h2',
    defaultUACSSProcessedProps: _cssProcessor.CSSProcessedProps.new().withProperty('fontSize', 24, nativeTextFlow) // TODO 1.5em
    .withProperty('marginTop', 13.28, nativeTextFlow) // TODO .83em
    .withProperty('marginBottom', 13.28, nativeTextFlow) // TODO .83em
    .merge(boldPropsRegistry)
  }),
  h3: new _HTMLElementModel.HTMLElementModel({
    category: 'sectioning',
    tagName: 'h3',
    defaultUACSSProcessedProps: _cssProcessor.CSSProcessedProps.new().withProperty('fontSize', 18.72, nativeTextFlow) // TODO 1.17em
    .withProperty('marginTop', 16, nativeTextFlow) // TODO 1em
    .withProperty('marginBottom', 16, nativeTextFlow) // TODO 1em
    .merge(boldPropsRegistry)
  }),
  h4: new _HTMLElementModel.HTMLElementModel({
    category: 'sectioning',
    tagName: 'h4',
    defaultUACSSProcessedProps: _cssProcessor.CSSProcessedProps.new().withProperty('fontSize', 16, nativeTextFlow) // TODO 1em
    .withProperty('marginTop', 21.28, nativeTextFlow) // TODO 1.33em
    .withProperty('marginBottom', 21.28, nativeTextFlow) // TODO 1.33em
    .merge(boldPropsRegistry)
  }),
  h5: new _HTMLElementModel.HTMLElementModel({
    category: 'sectioning',
    tagName: 'h5',
    defaultUACSSProcessedProps: _cssProcessor.CSSProcessedProps.new().withProperty('fontSize', 13.28, nativeTextFlow) // TODO .83em
    .withProperty('marginTop', 26.72, nativeTextFlow) // TODO 1.67em
    .withProperty('marginBottom', 26.72, nativeTextFlow) // TODO 1.67em
    .merge(boldPropsRegistry)
  }),
  h6: new _HTMLElementModel.HTMLElementModel({
    category: 'sectioning',
    tagName: 'h6',
    defaultUACSSProcessedProps: _cssProcessor.CSSProcessedProps.new().withProperty('fontSize', 10.72, nativeTextFlow) // TODO .67em
    .withProperty('marginTop', 37.28, nativeTextFlow) // TODO 2.33em
    .withProperty('marginBottom', 37.28, nativeTextFlow) // TODO 2.33em
    .merge(boldPropsRegistry)
  }),
  header: new _HTMLElementModel.HTMLElementModel({
    category: 'sectioning',
    tagName: 'header'
  }),
  hgroup: new _HTMLElementModel.HTMLElementModel({
    category: 'sectioning',
    tagName: 'hgroup'
  }),
  nav: new _HTMLElementModel.HTMLElementModel({
    category: 'sectioning',
    tagName: 'nav'
  }),
  section: new _HTMLElementModel.HTMLElementModel({
    category: 'sectioning',
    tagName: 'section'
  })
};
const unsupportedModelMap = {
  area: new _HTMLElementModel.HTMLElementModel({
    tagName: 'area',
    category: 'untranslatable',
    isVoid: true
  }),
  map: new _HTMLElementModel.HTMLElementModel({
    tagName: 'map',
    category: 'untranslatable'
  })
};
const attribsModelMap = {
  accesskey: new _HTMLElementModel.HTMLElementModel({
    tagName: 'accesskey',
    category: 'untranslatable'
  }),
  caption: new _HTMLElementModel.HTMLElementModel({
    tagName: 'caption',
    category: 'untranslatable'
  }),
  col: new _HTMLElementModel.HTMLElementModel({
    tagName: 'col',
    category: 'untranslatable',
    isVoid: true
  }),
  colgroup: new _HTMLElementModel.HTMLElementModel({
    tagName: 'colgroup',
    category: 'untranslatable'
  }),
  datalist: new _HTMLElementModel.HTMLElementModel({
    tagName: 'datalist',
    category: 'untranslatable'
  }),
  source: new _HTMLElementModel.HTMLElementModel({
    tagName: 'source',
    category: 'untranslatable',
    isVoid: true
  }),
  track: new _HTMLElementModel.HTMLElementModel({
    tagName: 'track',
    category: 'untranslatable',
    isVoid: true
  }),
  optgroup: new _HTMLElementModel.HTMLElementModel({
    tagName: 'optgroup',
    category: 'untranslatable'
  }),
  option: new _HTMLElementModel.HTMLElementModel({
    tagName: 'option',
    category: 'untranslatable'
  }),
  param: new _HTMLElementModel.HTMLElementModel({
    tagName: 'param',
    category: 'untranslatable',
    isVoid: true
  })
};
const interactiveModelMap = {
  button: new _HTMLElementModel.HTMLElementModel({
    tagName: 'button',
    category: 'interactive'
  }),
  fieldset: new _HTMLElementModel.HTMLElementModel({
    tagName: 'fieldset',
    category: 'interactive'
  }),
  form: new _HTMLElementModel.HTMLElementModel({
    tagName: 'form',
    category: 'interactive'
  }),
  input: new _HTMLElementModel.HTMLElementModel({
    tagName: 'input',
    category: 'interactive',
    isVoid: true
  }),
  label: new _HTMLElementModel.HTMLElementModel({
    tagName: 'label',
    category: 'interactive'
  }),
  legend: new _HTMLElementModel.HTMLElementModel({
    tagName: 'legend',
    category: 'interactive'
  }),
  meter: new _HTMLElementModel.HTMLElementModel({
    tagName: 'meter',
    category: 'interactive'
  }),
  progress: new _HTMLElementModel.HTMLElementModel({
    tagName: 'progress',
    category: 'interactive'
  }),
  select: new _HTMLElementModel.HTMLElementModel({
    tagName: 'select',
    category: 'interactive'
  }),
  details: new _HTMLElementModel.HTMLElementModel({
    tagName: 'details',
    category: 'interactive'
  }),
  dialog: new _HTMLElementModel.HTMLElementModel({
    tagName: 'dialog',
    category: 'interactive'
  }),
  output: new _HTMLElementModel.HTMLElementModel({
    tagName: 'output',
    category: 'interactive'
  }),
  summary: new _HTMLElementModel.HTMLElementModel({
    tagName: 'summary',
    category: 'interactive'
  }),
  textarea: new _HTMLElementModel.HTMLElementModel({
    tagName: 'textarea',
    category: 'interactive'
  })
};
const metadataModelMap = {
  base: new _HTMLElementModel.HTMLElementModel({
    tagName: 'base',
    category: 'untranslatable',
    isVoid: true
  }),
  head: new _HTMLElementModel.HTMLElementModel({
    tagName: 'head',
    category: 'untranslatable',
    isOpaque: true
  }),
  link: new _HTMLElementModel.HTMLElementModel({
    tagName: 'link',
    category: 'untranslatable',
    isVoid: true
  }),
  meta: new _HTMLElementModel.HTMLElementModel({
    tagName: 'meta',
    category: 'untranslatable',
    isVoid: true
  }),
  title: new _HTMLElementModel.HTMLElementModel({
    tagName: 'title',
    category: 'untranslatable'
  })
};
const untranslatableModelMap = { ...attribsModelMap,
  ...interactiveModelMap,
  ...unsupportedModelMap,
  ...metadataModelMap
};
const groupingModelMap = {
  blockquote: new _HTMLElementModel.HTMLElementModel({
    tagName: 'blockquote',
    category: 'grouping',
    getUADerivedCSSProcessedPropsFromAttributes: attributes => {
      if (attributes.type === 'cite') {
        return leftBorderQuote;
      }

      return null;
    },
    defaultUACSSProcessedProps: spacedBlockPropsRegistry
  }),
  dd: new _HTMLElementModel.HTMLElementModel({
    tagName: 'dd',
    category: 'grouping',
    defaultUACSSProcessedProps: _cssProcessor.CSSProcessedProps.new().withProperty('marginLeft', // TODO support directional styles
    30, nativeBlockRetain)
  }),
  div: new _HTMLElementModel.HTMLElementModel({
    tagName: 'div',
    category: 'grouping'
  }),
  dl: new _HTMLElementModel.HTMLElementModel({
    tagName: 'dl',
    category: 'grouping',
    defaultUACSSProcessedProps: bigMarginTopBottomPropsRegistry
  }),
  dt: new _HTMLElementModel.HTMLElementModel({
    tagName: 'dt',
    category: 'grouping',
    defaultUACSSProcessedProps: boldPropsRegistry
  }),
  figcaption: new _HTMLElementModel.HTMLElementModel({
    tagName: 'figcaption',
    category: 'grouping',
    defaultUACSSProcessedProps: _cssProcessor.CSSProcessedProps.new().withProperty('textAlign', 'center', nativeTextFlow).merge(italicPropsRegistry)
  }),
  figure: new _HTMLElementModel.HTMLElementModel({
    tagName: 'figure',
    category: 'grouping',
    defaultUACSSProcessedProps: spacedBlockPropsRegistry
  }),
  hr: new _HTMLElementModel.HTMLElementModel({
    tagName: 'hr',
    category: 'grouping',
    defaultUACSSProcessedProps: _cssProcessor.CSSProcessedProps.new().withProperty('marginLeft', 'auto', nativeBlockRetain).withProperty('marginRight', 'auto', nativeBlockRetain).withProperty('height', 1, nativeBlockRetain).withProperty('width', '100%', nativeBlockRetain).withProperty('backgroundColor', '#CCC', nativeBlockRetain).merge(shortMarginTopBottomPropsRegistry)
  }),
  li: new _HTMLElementModel.HTMLElementModel({
    tagName: 'li',
    category: 'grouping'
  }),
  main: new _HTMLElementModel.HTMLElementModel({
    tagName: 'main',
    category: 'grouping'
  }),
  menu: new _HTMLElementModel.HTMLElementModel({
    tagName: 'menu',
    category: 'grouping'
  }),
  ol: new _HTMLElementModel.HTMLElementModel({
    tagName: 'ol',
    category: 'grouping',
    defaultUACSSProcessedProps: _cssProcessor.CSSProcessedProps.new().withProperty('listStyleType', 'decimal', webTextFlow).merge(listPropsRegistry)
  }),
  p: new _HTMLElementModel.HTMLElementModel({
    tagName: 'p',
    category: 'grouping',
    defaultUACSSProcessedProps: bigMarginTopBottomPropsRegistry
  }),
  pre: new _HTMLElementModel.HTMLElementModel({
    tagName: 'pre',
    category: 'grouping',
    defaultUACSSProcessedProps: prePropsRegistry
  }),
  xmp: new _HTMLElementModel.HTMLElementModel({
    tagName: 'xmp',
    category: 'grouping',
    defaultUACSSProcessedProps: prePropsRegistry
  }),
  listing: new _HTMLElementModel.HTMLElementModel({
    tagName: 'listing',
    category: 'grouping',
    defaultUACSSProcessedProps: prePropsRegistry
  }),
  plaintext: new _HTMLElementModel.HTMLElementModel({
    tagName: 'plaintext',
    category: 'grouping',
    defaultUACSSProcessedProps: prePropsRegistry
  }),
  ul: new _HTMLElementModel.HTMLElementModel({
    tagName: 'ul',
    category: 'grouping',
    defaultUACSSProcessedProps: _cssProcessor.CSSProcessedProps.new().withProperty('listStyleType', 'disc', webTextFlow).merge(listPropsRegistry)
  }),
  dir: new _HTMLElementModel.HTMLElementModel({
    tagName: 'dir',
    category: 'grouping',
    // TODO list-style-type: disc;
    defaultUACSSProcessedProps: listPropsRegistry
  })
};
const tabularModelMap = {
  table: new _HTMLElementModel.HTMLElementModel({
    tagName: 'table',
    category: 'tabular'
  }),
  tbody: new _HTMLElementModel.HTMLElementModel({
    tagName: 'tbody',
    category: 'tabular'
  }),
  td: new _HTMLElementModel.HTMLElementModel({
    tagName: 'td',
    category: 'tabular'
  }),
  tfoot: new _HTMLElementModel.HTMLElementModel({
    tagName: 'tfoot',
    category: 'tabular'
  }),
  th: new _HTMLElementModel.HTMLElementModel({
    tagName: 'th',
    category: 'tabular'
  }),
  thead: new _HTMLElementModel.HTMLElementModel({
    tagName: 'thead',
    category: 'tabular'
  }),
  tr: new _HTMLElementModel.HTMLElementModel({
    tagName: 'tr',
    category: 'tabular'
  })
}; // Embedded elements are considered "opaque", i.e. no children are meant to be
// translated. A reference to domChildren will be available on the rendering
// end.

const embeddedModelMap = {
  audio: new _HTMLElementModel.HTMLElementModel({
    tagName: 'audio',
    category: 'embedded',
    isVoid: false // allows tracks

  }),
  canvas: new _HTMLElementModel.HTMLElementModel({
    tagName: 'canvas',
    category: 'embedded',
    isVoid: false // allows specific content

  }),
  embed: new _HTMLElementModel.HTMLElementModel({
    tagName: 'embed',
    category: 'embedded',
    isVoid: true
  }),
  iframe: new _HTMLElementModel.HTMLElementModel({
    tagName: 'iframe',
    category: 'embedded',
    isVoid: true
  }),
  img: new _HTMLElementModel.HTMLElementModel({
    tagName: 'img',
    category: 'embedded',
    isVoid: true
  }),
  math: new _HTMLElementModel.HTMLElementModel({
    tagName: 'math',
    category: 'embedded',
    isVoid: false // allows mathml elems

  }),
  object: new _HTMLElementModel.HTMLElementModel({
    tagName: 'object',
    category: 'embedded',
    isVoid: false // allows params

  }),
  picture: new _HTMLElementModel.HTMLElementModel({
    tagName: 'picture',
    category: 'embedded',
    isVoid: false // allows source and img

  }),
  svg: new _HTMLElementModel.HTMLElementModel({
    tagName: 'svg',
    category: 'embedded',
    isVoid: false // allows svg elems

  }),
  video: new _HTMLElementModel.HTMLElementModel({
    tagName: 'video',
    category: 'embedded',
    isVoid: false // allows source, tracks + transparent

  })
};
const editsModelMap = {
  ins: new _HTMLElementModel.HTMLElementModel({
    tagName: 'ins',
    category: 'edits',
    defaultUACSSProcessedProps: solidUnderlinePropsRegistry
  }),
  del: new _HTMLElementModel.HTMLElementModel({
    tagName: 'del',
    category: 'edits',
    defaultUACSSProcessedProps: lineThroughPropsRegistry
  })
};
const textLevelModelMap = {
  em: new _HTMLElementModel.HTMLElementModel({
    tagName: 'em',
    category: 'textual',
    defaultUACSSProcessedProps: italicPropsRegistry
  }),
  strong: new _HTMLElementModel.HTMLElementModel({
    tagName: 'strong',
    category: 'textual',
    defaultUACSSProcessedProps: boldPropsRegistry
  }),
  small: new _HTMLElementModel.HTMLElementModel({
    tagName: 'small',
    category: 'textual',
    defaultUACSSProcessedProps: _cssProcessor.CSSProcessedProps.new().withProperty('fontSize', 12, // TODO fix with "smaller"
    nativeTextFlow)
  }),
  big: new _HTMLElementModel.HTMLElementModel({
    tagName: 'big',
    category: 'textual',
    defaultUACSSProcessedProps: _cssProcessor.CSSProcessedProps.new().withProperty('fontSize', 24, // TODO fix with "larger"
    nativeTextFlow)
  }),
  s: new _HTMLElementModel.HTMLElementModel({
    tagName: 's',
    category: 'textual',
    defaultUACSSProcessedProps: lineThroughPropsRegistry
  }),
  strike: new _HTMLElementModel.HTMLElementModel({
    tagName: 'strike',
    category: 'textual',
    defaultUACSSProcessedProps: lineThroughPropsRegistry
  }),
  cite: new _HTMLElementModel.HTMLElementModel({
    tagName: 'cite',
    category: 'textual',
    defaultUACSSProcessedProps: italicPropsRegistry
  }),
  q: new _HTMLElementModel.HTMLElementModel({
    tagName: 'q',
    category: 'textual' // default style, content: "open,close-quote"

  }),
  dfn: new _HTMLElementModel.HTMLElementModel({
    tagName: 'dfn',
    category: 'textual',
    defaultUACSSProcessedProps: italicPropsRegistry
  }),
  abbr: new _HTMLElementModel.HTMLElementModel({
    tagName: 'abbr',
    category: 'textual',
    defaultUACSSProcessedProps: dottedUnderlinePropsRegistry
  }),
  acronym: new _HTMLElementModel.HTMLElementModel({
    tagName: 'acronym',
    category: 'textual',
    defaultUACSSProcessedProps: dottedUnderlinePropsRegistry
  }),
  ruby: new _HTMLElementModel.HTMLElementModel({
    tagName: 'ruby',
    category: 'textual'
  }),
  rt: new _HTMLElementModel.HTMLElementModel({
    tagName: 'rt',
    category: 'textual'
  }),
  rp: new _HTMLElementModel.HTMLElementModel({
    tagName: 'rp',
    category: 'textual'
  }),
  data: new _HTMLElementModel.HTMLElementModel({
    tagName: 'data',
    category: 'textual'
  }),
  time: new _HTMLElementModel.HTMLElementModel({
    tagName: 'time',
    category: 'textual'
  }),
  code: new _HTMLElementModel.HTMLElementModel({
    tagName: 'code',
    category: 'textual',
    defaultUACSSProcessedProps: monoPropsRegistry
  }),
  tt: new _HTMLElementModel.HTMLElementModel({
    tagName: 'tt',
    category: 'textual',
    defaultUACSSProcessedProps: monoPropsRegistry
  }),
  var: new _HTMLElementModel.HTMLElementModel({
    tagName: 'var',
    category: 'textual',
    defaultUACSSProcessedProps: italicPropsRegistry
  }),
  samp: new _HTMLElementModel.HTMLElementModel({
    tagName: 'samp',
    category: 'textual',
    defaultUACSSProcessedProps: monoPropsRegistry
  }),
  kbd: new _HTMLElementModel.HTMLElementModel({
    tagName: 'kbd',
    category: 'textual',
    defaultUACSSProcessedProps: monoPropsRegistry
  }),
  sub: new _HTMLElementModel.HTMLElementModel({
    tagName: 'sub',
    category: 'textual',
    defaultUACSSProcessedProps: _cssProcessor.CSSProcessedProps.new().withProperty('textAlignVertical', 'bottom', nativeTextRetain).withProperty('fontSize', 12, nativeTextFlow) // TODO fix to "smaller"

  }),
  sup: new _HTMLElementModel.HTMLElementModel({
    tagName: 'sup',
    category: 'textual',
    defaultUACSSProcessedProps: _cssProcessor.CSSProcessedProps.new().withProperty('textAlignVertical', 'top', nativeTextRetain).withProperty('fontSize', 12, nativeTextFlow) // TODO fix to "smaller"

  }),
  i: new _HTMLElementModel.HTMLElementModel({
    tagName: 'i',
    category: 'textual',
    defaultUACSSProcessedProps: italicPropsRegistry
  }),
  b: new _HTMLElementModel.HTMLElementModel({
    tagName: 'b',
    category: 'textual'
  }),
  u: new _HTMLElementModel.HTMLElementModel({
    tagName: 'u',
    category: 'textual',
    defaultUACSSProcessedProps: solidUnderlinePropsRegistry
  }),
  mark: new _HTMLElementModel.HTMLElementModel({
    tagName: 'mark',
    category: 'textual',
    defaultUACSSProcessedProps: _cssProcessor.CSSProcessedProps.new().withProperty('backgroundColor', 'yellow', nativeBlockRetain).withProperty('color', 'black', nativeTextFlow)
  }),
  bdi: new _HTMLElementModel.HTMLElementModel({
    tagName: 'bdi',
    category: 'textual' // unicode-bidi: isolate;

  }),
  bdo: new _HTMLElementModel.HTMLElementModel({
    tagName: 'bdo',
    category: 'textual' //  unicode-bidi: isolate-override;

  }),
  span: new _HTMLElementModel.HTMLElementModel({
    tagName: 'span',
    category: 'textual'
  }),
  br: new _HTMLElementModel.HTMLElementModel({
    tagName: 'br',
    category: 'textual',
    isVoid: true
  }),
  wbr: new _HTMLElementModel.HTMLElementModel({
    tagName: 'wbr',
    category: 'textual',
    isVoid: true
  })
};
const elementsModelMap = {
  a: new _HTMLElementModel.HTMLElementModel({
    tagName: 'a',
    category: 'anchor',
    getUADerivedCSSProcessedPropsFromAttributes: attributes => {
      if (typeof attributes.href === 'string') {
        return anchorPropsRegistry;
      }

      return null;
    }
  }),
  ...textLevelModelMap,
  ...editsModelMap,
  ...embeddedModelMap,
  ...tabularModelMap,
  ...groupingModelMap,
  ...sectioningModelMap,
  ...interactiveModelMap,
  ...untranslatableModelMap
};

function getElementModelFromTagName(tagName) {
  if (Object.prototype.hasOwnProperty.call(elementsModelMap, tagName)) {
    return elementsModelMap[tagName];
  }

  return new _HTMLElementModel.HTMLElementModel({
    tagName,
    category: 'custom'
  });
}
//# sourceMappingURL=elements-model.js.map