"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = tnodeToString;

var _TText = require("./tree/TText");

function tnodePropertiesString(tnode) {
  const tagPrint = tnode.tagName ? "tag=".concat(tnode.tagName) : 'anonymous';
  const idPrint = tnode.id ? "id=".concat(tnode.id) : null;
  const classesPrint = tnode.className ? "classes=".concat(tnode.className) : null;
  const dataPrint = tnode instanceof _TText.TText ? "data[".concat(tnode.data.length > 24 ? JSON.stringify(tnode.data.substring(0, 24)) + '…' : JSON.stringify(tnode.data), "]") : null; // @ts-ignore

  const anchorPrint = tnode.isAnchor ? "anchor[".concat(tnode.href, "]") : null;
  const detailsPrint = [tagPrint, idPrint, classesPrint, dataPrint, anchorPrint].filter(p => p !== null).join(',');
  return "\u2022".concat(tnode.displayName, "(").concat(detailsPrint, ")");
}

function tnodeToString(tnode, {
  parentLeftPrefix = '',
  isChild = false,
  isLast = false
} = {}) {
  const prefix = isChild ? isLast ? '└─' : '├─' : '';
  const totalPrefixLeft = parentLeftPrefix + prefix;
  const childrenPrint = tnode.children.map((c, i) => tnodeToString(c, {
    parentLeftPrefix: parentLeftPrefix + ' '.padStart(prefix.length, isChild && isLast ? ' ' : '│'),
    isChild: true,
    isLast: i === tnode.children.length - 1
  })).join('');
  return "".concat(totalPrefixLeft).concat(tnodePropertiesString(tnode), "\n").concat(childrenPrint);
}
//# sourceMappingURL=tnodeToString.js.map