import { CSSProcessedProps } from '@native-html/css-processor';
export declare type ElementCategory = 'anchor' | 'textual' | 'tabular' | 'edits' | 'embedded' | 'sectioning' | 'grouping' | 'interactive' | 'custom' | 'untranslatable';
export declare type TagName = AnchorTagName | TextLevelTagNames | EditsTagNames | EmbeddedTagNames | TabularTagNames | GroupingTagNames | SectioningTagNames | InteractiveTagNames | UntranslatableTagNames;
export declare type AnchorTagName = 'a';
export declare type TabularTagNames = 'table' | 'tbody' | 'thead' | 'tfoot' | 'tr' | 'td' | 'th';
export declare type GroupingTagNames = 'p' | 'hr' | 'pre' | 'blockquote' | 'ol' | 'ul' | 'dir' | 'menu' | 'li' | 'dl' | 'dt' | 'dd' | 'figure' | 'figcaption' | 'main' | 'div' | 'xmp' | 'listing' | 'plaintext';
export declare type AttribTagNames = 'accesskey' | 'datalist' | 'source' | 'track' | 'caption' | 'colgroup' | 'col' | 'option' | 'optgroup' | 'param';
export declare type MetadataTagNames = 'head' | 'title' | 'base' | 'link' | 'meta';
export declare type InteractiveTagNames = 'form' | 'label' | 'input' | 'button' | 'select' | 'progress' | 'meter' | 'fieldset' | 'legend' | 'textarea' | 'output' | 'details' | 'summary' | 'dialog';
export declare type UnsupportedTagNames = 'area' | 'map';
export declare type UntranslatableTagNames = AttribTagNames | UnsupportedTagNames | MetadataTagNames;
export declare type EmbeddedTagNames = 'audio' | 'canvas' | 'embed' | 'iframe' | 'img' | 'math' | 'object' | 'picture' | 'svg' | 'video';
export declare type EditsTagNames = 'ins' | 'del';
export declare type SectioningTagNames = 'body' | 'article' | 'section' | 'nav' | 'aside' | 'h1' | 'h2' | 'h3' | 'h4' | 'h5' | 'h6' | 'hgroup' | 'header' | 'footer' | 'address';
export declare type TextLevelTagNames = 'em' | 'strong' | 'strike' | 'small' | 'big' | 's' | 'cite' | 'q' | 'dfn' | 'abbr' | 'acronym' | 'ruby' | 'rt' | 'rp' | 'data' | 'time' | 'tt' | 'code' | 'var' | 'samp' | 'kbd' | 'sup' | 'sub' | 'i' | 'b' | 'u' | 'mark' | 'bdi' | 'bdo' | 'span' | 'br' | 'wbr';
export declare type CustomElementModel = ElementModelBase<string, 'custom'>;
export interface ElementModelBase<T = TagName, C = ElementCategory> {
    tagName: T;
    category: C;
    /**
     * An opaque element children should not be translated. Instead, a reference
     * to the dom node children should be used for rendering. Example: XML
     */
    isOpaque?: boolean;
    /**
     * Void elements such as specified in HTML4. Void elements cannot have children.
     */
    isVoid?: boolean;
    /**
     * Equivalent of "user-agent" styles.
     */
    defaultUACSSProcessedProps?: CSSProcessedProps;
    /**
     * For example, "width" and "height" attributes for &lt;img&gt; tags.
     */
    getUADerivedCSSProcessedPropsFromAttributes?: (attributes: Record<string, string>) => CSSProcessedProps | null;
}
export declare class HTMLElementModel<T extends string> {
    readonly tagName: T;
    readonly isOpaque: boolean;
    readonly isDocument: boolean;
    readonly isAnchor: boolean;
    readonly isPhrasing: boolean;
    readonly isTranslatableBlock: boolean;
    readonly isVoid: boolean;
    readonly defaultCSSProcessedProps: CSSProcessedProps | null;
    private readonly _getDerivedStylesFromAttributes;
    constructor({ tagName, category, isOpaque, isVoid, defaultUACSSProcessedProps: defaultCSSPropsRegistry, getUADerivedCSSProcessedPropsFromAttributes: getDerivedStylesFromAttributes }: ElementModelBase<T, ElementCategory>);
    getUADerivedCSSProcessedPropsFromAttributes(attributes: Record<string, string>): CSSProcessedProps | null;
}
