import { TStyles } from '../styles/TStyles';
import { SerializableNode } from '../dom/to-serializable';
import { TStylesMerger } from '../styles/TStylesMerger';
export interface TNodeInit {
    /**
     * Opaque nodes will hold a reference to a list of DOM children.
     */
    domChildren?: SerializableNode[];
    tagName?: string | null;
    attributes?: Record<string, string>;
    parentStyles: TStyles | null;
    styles?: TStyles;
    stylesMerger: TStylesMerger;
}
export declare type TNodeType = 'block' | 'phrasing' | 'text' | 'empty' | 'document';
export declare abstract class TNode implements TNodeInit {
    readonly type: TNodeType;
    readonly styles: TStyles;
    readonly attributes: Record<string, string>;
    readonly children: TNode[];
    readonly domChildren?: SerializableNode[];
    readonly tagName: string | null;
    readonly className: string | null;
    readonly id: string | null;
    readonly isAnchor: boolean;
    readonly parentStyles: TStyles | null;
    readonly hasWhiteSpaceCollapsingEnabled: boolean;
    readonly stylesMerger: TStylesMerger;
    abstract readonly displayName: string;
    constructor(init: TNodeInit, type: TNodeType);
    bindChildren(children: TNode[]): void;
    cloneInitParams<T extends TNodeInit = TNodeInit>(partial?: Partial<T>): T;
    isCollapsibleLeft(): boolean;
    isCollapsibleRight(): boolean;
    isWhitespace(): boolean;
    isEmpty(): boolean;
    trimLeft(): void;
    trimRight(): void;
}
